RelayClient

Struct RelayClient 

pub struct RelayClient {
    pub relayer_url: String,
    pub chain_id: u64,
    pub contract_config: SafeContractConfig,
    /* private fields */
}

Fields

relayer_url: Stringchain_id: u64contract_config: SafeContractConfig

Implementations

Source

impl RelayClient

pub fn new(relayer_url: impl Into<String>, chain_id: u64) -> Self

pub fn with_signer( self, signer: Box<dyn AbstractSigner + Send + Sync>, typed: Box<dyn AbstractSignerForCreate + Send + Sync>, ) -> Self

pub fn with_builder_api_key(self, creds: BuilderApiKeyCreds) -> Self

pub async fn get_nonce( &self, signer_address: &str, signer_type: &str, ) -> Result<NoncePayload>

pub async fn get_transaction( &self, transaction_id: &str, ) -> Result<Vec<RelayerTransaction>>

pub async fn get_transactions(&self) -> Result<Vec<RelayerTransaction>>

pub async fn get_deployed(&self, safe_address: &str) -> Result<bool>

pub async fn deploy(&self) -> Result<RelayerTransactionResponse>

pub async fn execute( &self, txns: Vec<SafeTransaction>, metadata: Option<String>, ) -> Result<RelayerTransactionResponse>

pub async fn execute_with_safe( &self, txns: Vec<SafeTransaction>, metadata: Option<String>, safe_address: Option<String>, ) -> Result<RelayerTransactionResponse>

Execute transactions with an optional explicit Safe address

If safe_address is provided, it will be used directly instead of deriving from signer address. This is useful when the Safe address is already known (e.g., from Polymarket account).

pub async fn poll_until_state( &self, transaction_id: &str, states: &[RelayerTransactionState], fail_state: Option<RelayerTransactionState>, max_polls: usize, poll_freq_ms: u64, ) -> Result<Option<RelayerTransaction>>